# Example datasets 

The example datasets are not part of the package distributed Python package `acore`,
but are used in the documentation and examples. This is done by downloading the data from
GitHub directly.

## PXD008541 - Human primary brown and white fat cell secretome

- [PXD008541](https://www.ebi.ac.uk/pride/archive/projects/PXD008541)

- used in `Download_PRIDE_data` recipe for documentation: 
  [LINK](https://analytics-core.readthedocs.io/en/latest/api_examples/Download_PRIDE_data.html)
- only metadata in sample names (which are in columns)

## PXD010372 - Ovarian cancer proteome

- [article](https://www.sciencedirect.com/science/article/pii/S0092867418311668) - data taken directly from supplementary tables
- PRIDE project [PXD010372](https://www.ebi.ac.uk/pride/archive/projects/PXD010372) - for reference
- some custom preprocessing done


## PXD016278 - Alzheimer Data

Proteome Profiling in Cerebrospinal Fluid Reveals Novel Biomarkers of Alzheimer's Disease

- [PXD016278](https://www.ebi.ac.uk/pride/archive/projects/PXD016278)
- [publication](https://www.embopress.org/doi/full/10.15252/msb.20199356)
- [curated data version from omiclearn](https://github.com/MannLabs/OmicLearn/tree/master/omiclearn/data)


Is currently still hosted on njab repo (can be moved), see [here](
https://github.com/RasmussenLab/njab/tree/main/docs/tutorial/data). Currently used in API 
recipe:
- [Normalization of samples in a dataset example](https://analytics-core.readthedocs.io/en/latest/api_examples/normalization_analysis.html)
